SlickNext class

emit when user wan to slide to next item

Inheritance

Constructors

SlickNext({Duration? duration, Curve? curve})
initialize the item

Properties

curve → Curve?
Curve for the slide animationj
final
duration → Duration?
The duration and curve arguments must not be null.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited